summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/rebar_config.erl2
-rw-r--r--src/rebar_erlc_compiler.erl4
2 files changed, 3 insertions, 3 deletions
diff --git a/src/rebar_config.erl b/src/rebar_config.erl
index 0127aff..bdc3fb5 100644
--- a/src/rebar_config.erl
+++ b/src/rebar_config.erl
@@ -41,7 +41,7 @@
-ifdef(namespaced_types).
%% dict:dict() exists starting from Erlang 17.
--type rebar_dict() :: dict:dict().
+-type rebar_dict() :: dict:dict(term(), term()).
-else.
%% dict() has been obsoleted in Erlang 17 and deprecated in 18.
-type rebar_dict() :: dict().
diff --git a/src/rebar_erlc_compiler.erl b/src/rebar_erlc_compiler.erl
index ae4503b..f628433 100644
--- a/src/rebar_erlc_compiler.erl
+++ b/src/rebar_erlc_compiler.erl
@@ -48,8 +48,8 @@
}).
-ifdef(namespaced_types).
-%% digraph:digraph() exists starting from Erlang 17.
--type rebar_digraph() :: digraph:digraph().
+%% digraph:graph() exists starting from Erlang 17.
+-type rebar_digraph() :: digraph:graph().
-else.
%% digraph() has been obsoleted in Erlang 17 and deprecated in 18.
-type rebar_digraph() :: digraph().